import request from '@/utils/request'

// 商户查询套餐列表
export function agentListSuit(query) {
  return request({
    url: '/agent/suit/list',
    method: 'get',
    params: query
  })
}

// 商户查询套餐详细
export function agentGetSuit(suitId) {
  return request({
    url: `/agent/suit/${suitId}`,
    method: 'get'
  })
}

// 商户删除套餐
export function agentDelSuit(suitId) {
  return request({
    url: '/agent/suit/' + suitId,
    method: 'delete'
  })
}

// 商户新增套餐
export function agentAddSuit(data) {
  return request({
    url: '/agent/suit/',
    method: 'post',
    data
  })
}

// 商户修改套餐
export function agentUpdateSuit(data) {
  return request({
    url: '/agent/suit/',
    method: 'put',
    data
  })
}
