<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="套餐名称" prop="name">
        <el-input
          v-model="queryParams.name"
          placeholder="请输入套餐名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
        >新增</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="suitList" @selection-change="handleSelectionChange">
      <el-table-column label="名称" align="center" prop="name"/>
      <!--      <el-table-column label="收费模式" align="center" prop="feeMode">-->
      <!--        <dict-tag slot-scope="d" :value="d.row.feeMode" :options="dict.type.suit_fee_mode"/>-->
      <!--      </el-table-column>-->
      <!--      <el-table-column label="收费类型" align="center" prop="feeType" width="160">-->
      <!--        <dict-tag slot-scope="d" :value="d.row.feeType" :options="dict.type.suit_fee_type"/>-->
      <!--      </el-table-column>-->
      <el-table-column label="价格" align="center" prop="price">
        <template slot-scope="d">{{d.row.price | money}} 元</template>
      </el-table-column>
      <el-table-column label="通电时长" align="center" prop="price" width="100">
        <template slot-scope="d">{{d.row.value}} {{suitTimeUnit(d.row.timeUnit)}}</template>
      </el-table-column>
      <el-table-column label="详细说明" align="center" prop="description" show-overflow-tooltip min-width="200"/>
      <el-table-column label="是否启用" align="center" prop="enabled">
        <el-switch slot-scope="d" v-model="d.row.enabled" @change="(nv) => {onChangeEnabled(d.row, nv)}"/>
      </el-table-column>
      <el-table-column label="创建时间" align="center" prop="createTime" width="180"/>
      <el-table-column label="排序" align="center" prop="sort"/>
      <el-table-column label="累计使用次数" align="center" prop="totalCount">
        <template slot-scope="d">{{d.row.totalCount}} 次</template>
      </el-table-column>
      <el-table-column label="应用场所" align="center" prop="storeList" min-width="200">
        <template slot-scope="d">
          <el-tag
            v-for="item in d.row.storeList"
            :key="item.storeId"
            @click="$router.push(`/mch/storeDetail?storeId=${item.storeId}`)"
            style="cursor: pointer; margin: 0 4px 2px 0;"
          >{{item.name}}</el-tag>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改套餐对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="700px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-row>
          <form-col :span="span" label="套餐名称" prop="name">
            <el-input v-model="form.name" placeholder="请输入套餐名称" />
          </form-col>
          <!--          <form-col :span="span" label="收费模式" prop="feeMode" >-->
          <!--            <el-select v-model="form.feeMode" style="width: 100%" @change="onChangeFeeMode">-->
          <!--              <el-option-->
          <!--                v-for="option of dict.type.suit_fee_mode"-->
          <!--                :key="option.value"-->
          <!--                :label="option.label"-->
          <!--                :value="option.value"-->
          <!--              />-->
          <!--            </el-select>-->
          <!--          </form-col>-->
          <!--          <form-col :span="span" label="收费方式" prop="feeType">-->
          <!--            <el-select v-model="form.feeType" style="width: 100%">-->
          <!--              <el-option-->
          <!--                v-for="option of dict.type.suit_fee_type"-->
          <!--                :key="option.value"-->
          <!--                :label="option.label"-->
          <!--                :value="option.value"-->
          <!--                :disabled="disabledFeeType(option)"-->
          <!--              />-->
          <!--            </el-select>-->
          <!--          </form-col>-->
          <form-col :span="span" label="价格" prop="price" v-if="[SuitFeeType.TIMING, SuitFeeType.COUNT].includes(form.feeType)">
            <el-input-number v-model="form.price" placeholder="请输入价格(元）" :min="0" :precision="2" controls-position="right" style="width: calc(100% - 2em)"/> 元
          </form-col>
          <form-col :span="span" label="押金" prop="price" v-else>
            <el-input-number v-model="form.price" placeholder="请输入押金(元）" :min="0" :precision="2" controls-position="right" style="width: calc(100% - 2em)"/> 元
          </form-col>
          <form-col :span="span" label="通电时间" prop="value" v-if="form.feeType === SuitFeeType.TIMING">
            <el-input v-model="form.value" placeholder="请输入通电时间" type="number">
              <template #append>
                <el-select v-model="form.timeUnit" style="width: 6em">
                  <el-option
                    v-for="option of dict.type.time_unit"
                    :key="option.value"
                    :label="option.label"
                    :value="option.value"
                  />
                </el-select>
              </template>
            </el-input>
          </form-col>
          <form-col :span="span" label="充值电量" prop="value" v-else-if="form.feeType === SuitFeeType.COUNT">
            <el-input v-model="form.value" placeholder="请输入充值电量" type="number">
              <template #append>度</template>
            </el-input>
          </form-col>
          <form-col :span="span" label="排序" prop="sort">
            <el-input-number v-model="form.sort" placeholder="请输入排序，值越大越靠后" style="width: 100%"/>
          </form-col>
          <form-col :span="span * 2" label="详细说明" prop="description">
            <el-input v-model="form.description" placeholder="请输入详细说明" type="textarea" />
          </form-col>
<!--          <form-col :span="span" label-width="0" v-for="(item, index) of 4" v-if="[SuitFeeType.TIME_COUNT, SuitFeeType.TIME_TIMING].includes(form.feeType)" >-->
<!--            <el-tooltip effect="dark" :content="`单击设置${item}档电价，双击全部设置为${item}档电价`" placement="top">-->
<!--              <el-button-->
<!--                :plain="amountIndex !== index"-->
<!--                :type="indexStyle[index]"-->
<!--                @click="handleSetAmountIndex(index)"-->
<!--                @dblclick.native="handleAllSet(index)">-->
<!--                {{item}}档电价-->
<!--              </el-button>-->
<!--            </el-tooltip>-->
<!--            <el-input-number v-model="form.gearAmount[index]" controls-position="right" placeholder="请输入电价" :precision="2" style="width: calc(100% - 11em)"/> {{gearUnit}}-->
<!--          </form-col>-->
<!--          <form-col :span="24" label-width="0"  v-if="[SuitFeeType.TIME_COUNT, SuitFeeType.TIME_TIMING].includes(form.feeType)">-->
<!--            <el-row>-->
<!--              <el-col :span="6" v-for="(item, index) of 24" :key="index" v-if="!refresh">-->
<!--                <el-button plain style="width: 100%" :type="timeType(index)" @click="handleClickTimeItem(index)">{{index}} 时</el-button>-->
<!--              </el-col>-->
<!--            </el-row>-->
<!--          </form-col>-->
          <form-col :span="span" label="启用自定义使用率" prop="enableCustomUse" label-width="9em">
            <el-switch v-model="form.enableCustomUse"/>
          </form-col>
          <form-col :span="span" label="自定义使用率" prop="usePoint" label-width="7em">
            <el-input-number v-model="form.usePoint" placeholder="请输入使用率" :min="0" :max="100" :precision="0" controls-position="right" style="width: calc(100% - 1.5em)"/> %
          </form-col>
          <form-col :span="span * 2" :label="`应用${FieldName.STORE}`" prop="storeIds" label-width="7em">
            <store-input v-model="form.storeIds" multiple/>
          </form-col>
        </el-row>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import DeviceInput from '@/components/Business/Device/DeviceInput.vue'
import { findLabel } from '@/utils'
import { agentAddSuit, agentDelSuit, agentGetSuit, agentListSuit, agentUpdateSuit } from '@/api/agent/suit'
import DeviceLink from '@/components/Business/Device/DeviceLink.vue'
import UserLink from '@/components/Business/SmUser/UserLink.vue'
import { updateSuit } from '@/api/ss/suit'
import StoreInput from '@/components/Business/Store/StoreInput.vue'
import { FieldName, SuitFeeType } from '@/utils/constants'
import { agentListStore, agentListStoreByIds } from '@/api/agent/store'
import UserInput from '@/components/Business/SmUser/UserInput.vue'

export default {
  name: "MchSuit",
  dicts: ['time_unit'],
  computed: {
    SuitFeeType() {
      return SuitFeeType
    },
    FieldName() {
      return FieldName
    },
    // 时长单位
    suitTimeUnit() {
      return (unit) => {
        return findLabel(this.dict.type.time_unit, unit);
      }
    }
  },
  components: { UserInput, StoreInput, UserLink, DeviceLink, DeviceInput },
  data() {
    return {
      span: 12,
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 套餐表格数据
      suitList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        deviceId: null,
        name: null,
        feeType: null,
        value: null,
        price: null,
        description: null,
        deleted: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        name: [
          { required: true, message: "套餐名称不能为空", trigger: "blur" }
        ],
        value: [
          { required: true, message: "通电时间不能为空", trigger: "blur" }
        ],
        price: [
          { required: true, message: "价格不能为空", trigger: "blur" }
        ],
      }
    };
  },
  mounted() {
    this.getList();
  },
  methods: {
    agentListStoreByIds,
    agentListStore,
    onChangeEnabled(row, nv) {
      agentUpdateSuit({suitId: row.suitId, enabled: nv}).then(res => {
        if (res.code !== 200) {
          this.$message.error("修改是否启用失败");
          this.getList();
        }
      })
    },
    /** 查询套餐列表 */
    getList() {
      this.loading = true;
      agentListSuit(this.queryParams).then(response => {
        this.suitList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        suitId: null,
        name: null,
        value: null,
        price: null,
        description: null,
        timeUnit: "2",
        feeType: "1",
        feeMode: "1",
        gearAmount: [0,0,0,0],
        gearTime: [],
        deptId: this.deptId,
        sort: 0,
        enableCustomUse: false,
        storeIds: []
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.suitId)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加套餐";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const suitId = row.suitId || this.ids
      agentGetSuit(suitId).then(response => {
        let data = response.data;
        data.storeIds = data.storeList.map(item => item.storeId);
        this.form = data;
        this.open = true;
        this.title = "修改套餐";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.suitId != null) {
            agentUpdateSuit(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            agentAddSuit(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      this.$modal.confirm(`是否确认删除套餐 "${row.name}" ?`).then(function() {
        return agentDelSuit(row.suitId);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('ss/suit/export', {
        ...this.queryParams
      }, `suit_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
